@@ -66,6 +66,8 @@ __all__ = [
     "SDL_HINT_JOYSTICK_THREAD",
     "SDL_HINT_KMSDRM_REQUIRE_DRM_MASTER",
     "SDL_HINT_JOYSTICK_DEVICE",
+    "SDL_HINT_LINUX_DIGITAL_HATS",
+    "SDL_HINT_LINUX_HAT_DEADZONES",
     "SDL_HINT_LINUX_JOYSTICK_CLASSIC",
     "SDL_HINT_LINUX_JOYSTICK_DEADZONES",
     "SDL_HINT_MAC_BACKGROUND_APP",
@@ -115,6 +117,7 @@ __all__ = [
     "SDL_HINT_VIDEO_MINIMIZE_ON_FOCUS_LOSS",
     "SDL_HINT_VIDEO_WAYLAND_ALLOW_LIBDECOR",
     "SDL_HINT_VIDEO_WAYLAND_PREFER_LIBDECOR",
+    "SDL_HINT_VIDEO_WAYLAND_MODE_EMULATION",
     "SDL_HINT_VIDEO_WINDOW_SHARE_PIXEL_FORMAT",
     "SDL_HINT_VIDEO_FOREIGN_WINDOW_OPENGL",
     "SDL_HINT_VIDEO_FOREIGN_WINDOW_VULKAN",
@@ -137,6 +140,8 @@ __all__ = [
     "SDL_HINT_WINDOWS_INTRESOURCE_ICON_SMALL",
     "SDL_HINT_WINDOWS_NO_CLOSE_ON_ALT_F4",
     "SDL_HINT_WINDOWS_USE_D3D9EX",
+    "SDL_HINT_WINDOWS_DPI_AWARENESS",
+    "SDL_HINT_WINDOWS_DPI_SCALING",
     "SDL_HINT_WINDOW_FRAME_USABLE_WHILE_CURSOR_HIDDEN",
     "SDL_HINT_WINDOW_NO_ACTIVATION_WHEN_SHOWN",
     "SDL_HINT_WINRT_HANDLE_BACK_BUTTON",
@@ -196,6 +201,7 @@ SDL_HINT_VIDEO_FOREIGN_WINDOW_OPENGL = b"SDL_VIDEO_FOREIGN_WINDOW_OPENGL"
 SDL_HINT_VIDEO_FOREIGN_WINDOW_VULKAN = b"SDL_VIDEO_FOREIGN_WINDOW_VULKAN"
 SDL_HINT_VIDEO_WAYLAND_ALLOW_LIBDECOR = b"SDL_VIDEO_WAYLAND_ALLOW_LIBDECOR"
 SDL_HINT_VIDEO_WAYLAND_PREFER_LIBDECOR = b"SDL_VIDEO_WAYLAND_PREFER_LIBDECOR"
+SDL_HINT_VIDEO_WAYLAND_MODE_EMULATION = b"SDL_VIDEO_WAYLAND_MODE_EMULATION"
 SDL_HINT_VIDEO_WINDOW_SHARE_PIXEL_FORMAT = b"SDL_VIDEO_WINDOW_SHARE_PIXEL_FORMAT"
 SDL_HINT_VIDEO_X11_FORCE_EGL = b"SDL_VIDEO_X11_FORCE_EGL"
 SDL_HINT_VIDEO_X11_NET_WM_BYPASS_COMPOSITOR = b"SDL_VIDEO_X11_NET_WM_BYPASS_COMPOSITOR"
@@ -295,6 +301,8 @@ SDL_HINT_JOYSTICK_DEVICE = b"SDL_JOYSTICK_DEVICE"
 SDL_HINT_EMSCRIPTEN_ASYNCIFY = b"SDL_EMSCRIPTEN_ASYNCIFY"
 SDL_HINT_EMSCRIPTEN_KEYBOARD_ELEMENT = b"SDL_EMSCRIPTEN_KEYBOARD_ELEMENT"
 SDL_HINT_KMSDRM_REQUIRE_DRM_MASTER = b"SDL_KMSDRM_REQUIRE_DRM_MASTER"
+SDL_HINT_LINUX_DIGITAL_HATS = b"SDL_LINUX_DIGITAL_HATS"
+SDL_HINT_LINUX_HAT_DEADZONES = b"SDL_LINUX_HAT_DEADZONES"
 SDL_HINT_LINUX_JOYSTICK_CLASSIC = b"SDL_LINUX_JOYSTICK_CLASSIC"
 SDL_HINT_LINUX_JOYSTICK_DEADZONES = b"SDL_LINUX_JOYSTICK_DEADZONES"
 SDL_HINT_MAC_BACKGROUND_APP = b"SDL_MAC_BACKGROUND_APP"
@@ -312,6 +320,8 @@ SDL_HINT_WINDOWS_FORCE_SEMAPHORE_KERNEL = b"SDL_WINDOWS_FORCE_SEMAPHORE_KERNEL"
 SDL_HINT_WINDOWS_INTRESOURCE_ICON = b"SDL_WINDOWS_INTRESOURCE_ICON"
 SDL_HINT_WINDOWS_INTRESOURCE_ICON_SMALL = b"SDL_WINDOWS_INTRESOURCE_ICON_SMALL"
 SDL_HINT_WINDOWS_USE_D3D9EX = b"SDL_WINDOWS_USE_D3D9EX"
+SDL_HINT_WINDOWS_DPI_AWARENESS = b"SDL_WINDOWS_DPI_AWARENESS"
+SDL_HINT_WINDOWS_DPI_SCALING = b"SDL_WINDOWS_DPI_SCALING"
 SDL_HINT_XINPUT_ENABLED = b"SDL_XINPUT_ENABLED"
 SDL_HINT_XINPUT_USE_OLD_JOYSTICK_MAPPING = b"SDL_XINPUT_USE_OLD_JOYSTICK_MAPPING"
 
