@@ -56,8 +56,8 @@ _bind = dll.bind_function
 # Constants, enums, type definitions, and macros
 
 SDL_TTF_MAJOR_VERSION = 2
-SDL_TTF_MINOR_VERSION = 0
-SDL_TTF_PATCHLEVEL = 18
+SDL_TTF_MINOR_VERSION = 20
+SDL_TTF_PATCHLEVEL = 0
 
 def SDL_TTF_VERSION(x):
     x.major = SDL_TTF_MAJOR_VERSION
@@ -69,7 +69,9 @@ TTF_MINOR_VERSION = SDL_TTF_MINOR_VERSION
 TTF_PATCHLEVEL = SDL_TTF_PATCHLEVEL
 TTF_VERSION = SDL_TTF_VERSION
 
-SDL_TTF_COMPILEDVERSION = SDL_VERSIONNUM(SDL_TTF_MAJOR_VERSION, SDL_TTF_MINOR_VERSION, SDL_TTF_PATCHLEVEL)
+SDL_TTF_COMPILEDVERSION = SDL_VERSIONNUM(
+    SDL_TTF_MAJOR_VERSION, SDL_TTF_MINOR_VERSION, SDL_TTF_PATCHLEVEL
+)
 SDL_TTF_VERSION_ATLEAST = lambda x, y, z: (SDL_TTF_COMPILEDVERSION >= SDL_VERSIONNUM(x, y, z))
 
 UNICODE_BOM_NATIVE = 0xFEFF
@@ -87,6 +89,16 @@ TTF_HINTING_MONO = 2
 TTF_HINTING_NONE = 3
 TTF_HINTING_LIGHT_SUBPIXEL = 4
 
+TTF_WRAPPED_ALIGN_LEFT = 0
+TTF_WRAPPED_ALIGN_CENTER = 1
+TTF_WRAPPED_ALIGN_RIGHT = 2
+
+TTF_Direction = c_int
+TTF_DIRECTION_LTR = 0
+TTF_DIRECTION_RTL = 1
+TTF_DIRECTION_TTB = 2
+TTF_DIRECTION_BTT = 3
+
 class TTF_Font(c_void_p):
     """The opaque data type for fonts opened using the TTF library.
     
@@ -139,9 +151,18 @@ _funcdefs = [
     SDLFunc("TTF_OpenFontRW", [_P(SDL_RWops), c_int, c_int], _P(TTF_Font)),
     SDLFunc("TTF_OpenFontIndexRW", [_P(SDL_RWops), c_int, c_int, c_long], _P(TTF_Font)),
     SDLFunc("TTF_OpenFontDPI", [c_char_p, c_int, c_uint, c_uint], _P(TTF_Font), added='2.0.18'),
-    SDLFunc("TTF_OpenFontIndexDPI", [c_char_p, c_int, c_long, c_uint, c_uint], _P(TTF_Font), added='2.0.18'),
-    SDLFunc("TTF_OpenFontDPIRW", [_P(SDL_RWops), c_int, c_int, c_uint, c_uint], _P(TTF_Font), added='2.0.18'),
-    SDLFunc("TTF_OpenFontIndexDPIRW", [_P(SDL_RWops), c_int, c_int, c_long, c_uint, c_uint], _P(TTF_Font), added='2.0.18'),
+    SDLFunc("TTF_OpenFontIndexDPI",
+        [c_char_p, c_int, c_long, c_uint, c_uint],
+        returns = _P(TTF_Font), added = '2.0.18'
+    ),
+    SDLFunc("TTF_OpenFontDPIRW",
+        [_P(SDL_RWops), c_int, c_int, c_uint, c_uint],
+        returns = _P(TTF_Font), added = '2.0.18'
+    ),
+    SDLFunc("TTF_OpenFontIndexDPIRW",
+        [_P(SDL_RWops), c_int, c_int, c_long, c_uint, c_uint],
+        returns = _P(TTF_Font), added = '2.0.18'
+    ),
     SDLFunc("TTF_SetFontSize", [_P(TTF_Font), c_int], c_int, added='2.0.18'),
     SDLFunc("TTF_SetFontSizeDPI", [_P(TTF_Font), c_int, c_uint, c_uint], c_int, added='2.0.18'),
     SDLFunc("TTF_GetFontStyle", [_P(TTF_Font)], c_int),
@@ -150,6 +171,8 @@ _funcdefs = [
     SDLFunc("TTF_SetFontOutline", [_P(TTF_Font), c_int], None),
     SDLFunc("TTF_GetFontHinting", [_P(TTF_Font)], c_int),
     SDLFunc("TTF_SetFontHinting", [_P(TTF_Font), c_int], None),
+    SDLFunc("TTF_GetFontWrappedAlign", [_P(TTF_Font)], c_int, added='2.20.0'),
+    SDLFunc("TTF_SetFontWrappedAlign", [_P(TTF_Font), c_int], None, added='2.20.0'),
     SDLFunc("TTF_FontHeight", [_P(TTF_Font)], c_int),
     SDLFunc("TTF_FontAscent", [_P(TTF_Font)], c_int),
     SDLFunc("TTF_FontDescent", [_P(TTF_Font)], c_int),
@@ -162,46 +185,149 @@ _funcdefs = [
     SDLFunc("TTF_FontFaceStyleName", [_P(TTF_Font)], c_char_p),
     SDLFunc("TTF_GlyphIsProvided", [_P(TTF_Font), Uint16], c_int),
     SDLFunc("TTF_GlyphIsProvided32", [_P(TTF_Font), Uint32], c_int, added='2.0.18'),
-    SDLFunc("TTF_GlyphMetrics", [_P(TTF_Font), Uint16, _P(c_int), _P(c_int), _P(c_int), _P(c_int), _P(c_int)], c_int),
-    SDLFunc("TTF_GlyphMetrics32", [_P(TTF_Font), Uint32, _P(c_int), _P(c_int), _P(c_int), _P(c_int), _P(c_int)], c_int, added='2.0.18'),
+    SDLFunc("TTF_GlyphMetrics",
+        [_P(TTF_Font), Uint16, _P(c_int), _P(c_int), _P(c_int), _P(c_int), _P(c_int)],
+        returns = c_int
+    ),
+    SDLFunc("TTF_GlyphMetrics32",
+        [_P(TTF_Font), Uint32, _P(c_int), _P(c_int), _P(c_int), _P(c_int), _P(c_int)],
+        returns = c_int, added = '2.0.18'
+    ),
     SDLFunc("TTF_SizeText", [_P(TTF_Font), c_char_p, _P(c_int), _P(c_int)], c_int),
     SDLFunc("TTF_SizeUTF8", [_P(TTF_Font), c_char_p, _P(c_int), _P(c_int)], c_int),
     SDLFunc("TTF_SizeUNICODE", [_P(TTF_Font), _P(Uint16), _P(c_int), _P(c_int)], c_int),
-    SDLFunc("TTF_MeasureText", [_P(TTF_Font), c_char_p, c_int, _P(c_int), _P(c_int)], c_int, added='2.0.18'),
-    SDLFunc("TTF_MeasureUTF8", [_P(TTF_Font), c_char_p, c_int, _P(c_int), _P(c_int)], c_int, added='2.0.18'),
-    SDLFunc("TTF_MeasureUNICODE", [_P(TTF_Font), _P(Uint16), c_int, _P(c_int), _P(c_int)], c_int, added='2.0.18'),
+    SDLFunc("TTF_MeasureText",
+        [_P(TTF_Font), c_char_p, c_int, _P(c_int), _P(c_int)],
+        returns = c_int, added = '2.0.18'
+    ),
+    SDLFunc("TTF_MeasureUTF8",
+        [_P(TTF_Font), c_char_p, c_int, _P(c_int), _P(c_int)],
+        returns = c_int, added = '2.0.18'
+    ),
+    SDLFunc("TTF_MeasureUNICODE",
+        [_P(TTF_Font), _P(Uint16), c_int, _P(c_int), _P(c_int)],
+        returns = c_int, added = '2.0.18'
+    ),
     SDLFunc("TTF_RenderText_Solid", [_P(TTF_Font), c_char_p, SDL_Color], _P(SDL_Surface)),
     SDLFunc("TTF_RenderUTF8_Solid", [_P(TTF_Font), c_char_p, SDL_Color], _P(SDL_Surface)),
     SDLFunc("TTF_RenderUNICODE_Solid", [_P(TTF_Font), _P(Uint16), SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderText_Solid_Wrapped", [_P(TTF_Font), c_char_p, SDL_Color, Uint32], _P(SDL_Surface), added='2.0.18'),
-    SDLFunc("TTF_RenderUTF8_Solid_Wrapped", [_P(TTF_Font), c_char_p, SDL_Color, Uint32], _P(SDL_Surface), added='2.0.18'),
-    SDLFunc("TTF_RenderUNICODE_Solid_Wrapped", [_P(TTF_Font), _P(Uint16), SDL_Color, Uint32], _P(SDL_Surface), added='2.0.18'),
+    SDLFunc("TTF_RenderText_Solid_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderUTF8_Solid_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderUNICODE_Solid_Wrapped",
+        [_P(TTF_Font), _P(Uint16), SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
     SDLFunc("TTF_RenderGlyph_Solid", [_P(TTF_Font), Uint16, SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderGlyph32_Solid", [_P(TTF_Font), Uint32, SDL_Color], _P(SDL_Surface), added='2.0.18'),
-    SDLFunc("TTF_RenderText_Shaded", [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderUTF8_Shaded", [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderUNICODE_Shaded", [_P(TTF_Font), _P(Uint16), SDL_Color, SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderText_Shaded_Wrapped", [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color, Uint32], _P(SDL_Surface), added='2.0.18'),
-    SDLFunc("TTF_RenderUTF8_Shaded_Wrapped", [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color, Uint32], _P(SDL_Surface), added='2.0.18'),
-    SDLFunc("TTF_RenderUNICODE_Shaded_Wrapped", [_P(TTF_Font), _P(Uint16), SDL_Color, SDL_Color, Uint32], _P(SDL_Surface), added='2.0.18'),
-    SDLFunc("TTF_RenderGlyph_Shaded", [_P(TTF_Font), Uint16, SDL_Color, SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderGlyph32_Shaded", [_P(TTF_Font), Uint32, SDL_Color, SDL_Color], _P(SDL_Surface), added='2.0.18'),
+    SDLFunc("TTF_RenderGlyph32_Solid",
+        [_P(TTF_Font), Uint32, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderText_Shaded",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface)
+    ),
+    SDLFunc("TTF_RenderUTF8_Shaded",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface)
+    ),
+    SDLFunc("TTF_RenderUNICODE_Shaded",
+        [_P(TTF_Font), _P(Uint16), SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface)
+    ),
+    SDLFunc("TTF_RenderText_Shaded_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderUTF8_Shaded_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderUNICODE_Shaded_Wrapped",
+        [_P(TTF_Font), _P(Uint16), SDL_Color, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderGlyph_Shaded",
+        [_P(TTF_Font), Uint16, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface)
+    ),
+    SDLFunc("TTF_RenderGlyph32_Shaded",
+        [_P(TTF_Font), Uint32, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
     SDLFunc("TTF_RenderText_Blended", [_P(TTF_Font), c_char_p, SDL_Color], _P(SDL_Surface)),
     SDLFunc("TTF_RenderUTF8_Blended", [_P(TTF_Font), c_char_p, SDL_Color], _P(SDL_Surface)),
     SDLFunc("TTF_RenderUNICODE_Blended", [_P(TTF_Font), _P(Uint16), SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderText_Blended_Wrapped", [_P(TTF_Font), c_char_p, SDL_Color, Uint32], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderUTF8_Blended_Wrapped", [_P(TTF_Font), c_char_p, SDL_Color, Uint32], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderUNICODE_Blended_Wrapped", [_P(TTF_Font), _P(Uint16), SDL_Color, Uint32], _P(SDL_Surface)),
+    SDLFunc("TTF_RenderText_Blended_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, Uint32],
+        returns = _P(SDL_Surface)
+    ),
+    SDLFunc("TTF_RenderUTF8_Blended_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, Uint32],
+        returns = _P(SDL_Surface)
+    ),
+    SDLFunc("TTF_RenderUNICODE_Blended_Wrapped",
+        [_P(TTF_Font), _P(Uint16), SDL_Color, Uint32],
+        returns = _P(SDL_Surface)
+    ),
     SDLFunc("TTF_RenderGlyph_Blended", [_P(TTF_Font), Uint16, SDL_Color], _P(SDL_Surface)),
-    SDLFunc("TTF_RenderGlyph32_Blended", [_P(TTF_Font), Uint32, SDL_Color], _P(SDL_Surface), added='2.0.18'),
+    SDLFunc("TTF_RenderGlyph32_Blended",
+        [_P(TTF_Font), Uint32, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.0.18'
+    ),
+    SDLFunc("TTF_RenderText_LCD",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderUTF8_LCD",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderUNICODE_LCD",
+        [_P(TTF_Font), _P(Uint16), SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderText_LCD_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderUTF8_LCD_Wrapped",
+        [_P(TTF_Font), c_char_p, SDL_Color, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderUNICODE_LCD_Wrapped",
+        [_P(TTF_Font), _P(Uint16), SDL_Color, SDL_Color, Uint32],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderGlyph_LCD",
+        [_P(TTF_Font), Uint16, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
+    SDLFunc("TTF_RenderGlyph32_LCD",
+        [_P(TTF_Font), Uint32, SDL_Color, SDL_Color],
+        returns = _P(SDL_Surface), added = '2.20.0'
+    ),
     SDLFunc("TTF_SetDirection", [c_int], c_int, added='2.0.18'),
     SDLFunc("TTF_SetScript", [c_int], c_int, added='2.0.18'),
+    SDLFunc("TTF_SetFontDirection", [_P(TTF_Font), TTF_Direction], c_int, added='2.20.0'),
+    SDLFunc("TTF_SetFontScriptName", [_P(TTF_Font), c_char_p], c_int, added='2.20.0'),
     SDLFunc("TTF_CloseFont", [_P(TTF_Font)]),
     SDLFunc("TTF_Quit"),
     SDLFunc("TTF_WasInit", None, c_int),
     SDLFunc("TTF_GetFontKerningSize", [_P(TTF_Font), c_int, c_int], c_int),
-    SDLFunc("TTF_GetFontKerningSizeGlyphs", [_P(TTF_Font), Uint16, Uint16], c_int, added='2.0.14'),
-    SDLFunc("TTF_GetFontKerningSizeGlyphs32", [_P(TTF_Font), Uint32, Uint32], c_int, added='2.0.18'),
+    SDLFunc("TTF_GetFontKerningSizeGlyphs",
+        [_P(TTF_Font), Uint16, Uint16],
+        returns = c_int, added = '2.0.14'
+    ),
+    SDLFunc("TTF_GetFontKerningSizeGlyphs32",
+        [_P(TTF_Font), Uint32, Uint32],
+        returns = c_int, added = '2.0.18'
+    ),
     SDLFunc("TTF_SetFontSDF", [_P(TTF_Font), SDL_bool], c_int, added='2.0.18'),
     SDLFunc("TTF_GetFontSDF", [_P(TTF_Font)], SDL_bool, added='2.0.18'),
 ]
@@ -641,6 +767,50 @@ def TTF_SetFontHinting(font, hinting):
     """
     return _ctypes["TTF_SetFontHinting"](font, hinting)
 
+def TTF_GetFontWrappedAlign(font):
+    """Retrieves the current wrapping alignment for a given font.
+
+    This function returns one of the constants specified in the documentation
+    for :func:`TTF_SetFontWrappedAlign`.
+
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object for which the alignment type
+            should be retrieved.
+    
+    Returns:
+        int: A constant indicating the current wrap alignment for the font.
+
+    """
+    return _ctypes["TTF_GetFontWrappedAlign"](font)
+
+def TTF_SetFontWrappedAlign(font, align):
+    """Sets the alignment to use when rendering wrapped text with a given font.
+    
+    The alignment type can be specified using one of the following constants:
+
+    ================ ==============================
+    Alignment        Constant
+    ================ ==============================
+    Left-justified   ``TTF_WRAPPED_ALIGN_LEFT``
+    Centered         ``TTF_WRAPPED_ALIGN_CENTER``
+    Right-justified  ``TTF_WRAPPED_ALIGN_RIGHT``
+    ================ ==============================
+
+    Wrapped text will be left-justified if no alignment is explicitly set.
+
+    `Note: Added in SDL_ttf 2.20.0`
+   
+    Args:
+        font (:obj:`TTF_Font`): The font object for which the alignment type
+            will be set.
+        align (int): A constant specifiying the aligmnent to use when rendering
+            wrapped text.
+
+    """
+    return _ctypes["TTF_SetFontWrappedAlign"](font, align)
+
 
 def TTF_FontHeight(font):
     """Gets the maximum pixel height of all glyphs in a given font.
@@ -1429,12 +1599,13 @@ def TTF_RenderText_Blended(font, text, fg):
 
     The ``Blended`` family of TTF functions render text to a 32-bit ARGB
     :obj:`SDL_Surface` with antialiasing and background transparency.
-    This is the highest quality (and slowest) of all TTF rendering types.
 
     The rendered text will be antialiased on a transparent surface using alpha
     blending. This rendering type should be used in cases when you want to
     overlay the rendered text over something else, and in in most other cases
-    where high performance isn't the primary concern.
+    where high performance isn't the primary concern. For rendering high-quality
+    text on a solid background or at smaller font sizes, see the ``LCD`` family
+    of rendering functions.
 
     .. note::
        To render an RGBA surface instead of an ARGB one, just swap the R and B
@@ -1578,6 +1749,178 @@ def TTF_RenderGlyph32_Blended(font, ch, fg):
     """
     return _ctypes["TTF_RenderGlyph32_Blended"](font, ch, fg)
 
+
+def TTF_RenderText_LCD(font, text, fg, bg):
+    """Renders an ASCII-encoded string to a solid 32-bit surface.
+
+    The ``LCD`` family of TTF functions render text to av32-bit ARGB
+    :obj:`SDL_Surface` with high-quality subpixel rendering. This should
+    produce better results at small sizes than :func:`TTF_RenderText_Shaded`,
+    but may be slower and requires a solid background colour for best results.
+    
+    .. note::
+       To render an RGBA surface instead of an ARGB one, just swap the R and B
+       values when creating the foreground and background colors.
+    
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        text (bytes): An ASCII-encoded bytestring of text to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the text.
+        bg (:obj:`SDL_Color`): The background fill color for the text.
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered text, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderText_LCD"](font, text, fg, bg)
+
+def TTF_RenderUTF8_LCD(font, text, fg, bg):
+    """Renders a UTF8-encoded string to a solid antialiased 32-bit surface.
+
+    See :func:`TTF_RenderText_LCD` for more details on the rendering style.
+    
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        text (bytes): A UTF8-encoded bytestring of text to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the text.
+        bg (:obj:`SDL_Color`): The background fill color for the text.
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered text, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderUTF8_LCD"](font, text, fg, bg)
+
+def TTF_RenderUNICODE_LCD(font, text, fg, bg):
+    """Renders a UCS-2 encoded string to a solid antialiased 32-bit surface.
+
+    See :func:`TTF_RenderText_LCD` for more details on the rendering style,
+    and :func:`TTF_RenderUNICODE_Solid` for documentation of the text format.
+    
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        text (byref(:obj:`~ctypes.c_uint16`)): A ctypes array containing a UCS-2
+            encoded string of text to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the text.
+        bg (:obj:`SDL_Color`): The background fill color for the text.
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered text, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderUNICODE_LCD"](font, text, fg, bg)
+
+def TTF_RenderText_LCD_Wrapped(font, text, fg, bg, wrapLength):
+    """Renders an ASCII-encoded string to a solid antialiased 32-bit surface.
+
+    This function is identical to :func:`TTF_RenderText_LCD`, except that
+    any lines exceeding the specified wrap length will be wrapped to fit within
+    the given width.
+
+    `Note: Added in SDL_ttf 2.20.0`
+   
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        text (bytes): An ASCII-encoded bytestring of text to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the text.
+        bg (:obj:`SDL_Color`): The background fill color for the text.
+        wrapLength (int): The maximum width of the output surface (in pixels)
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered text, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderText_LCD_Wrapped"](font, text, fg, bg, wrapLength)
+
+def TTF_RenderUTF8_LCD_Wrapped(font, text, fg, bg, wrapLength):
+    """Renders a UTF8-encoded string to a solid antialiased 32-bit surface.
+
+    This function is identical to :func:`TTF_RenderUTF8_LCD`, except that
+    any lines exceeding the specified wrap length will be wrapped to fit within
+    the given width.
+
+    `Note: Added in SDL_ttf 2.20.0`
+   
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        text (byref(:obj:`~ctypes.c_uint16`)): A ctypes array containing a UCS-2
+            encoded string of text to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the text.
+        bg (:obj:`SDL_Color`): The background fill color for the text.
+        wrapLength (int): The maximum width of the output surface (in pixels)
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered text, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderUTF8_LCD_Wrapped"](font, text, fg, bg, wrapLength)
+
+def TTF_RenderUNICODE_LCD_Wrapped(font, text, fg, bg, wrapLength):
+    """Renders a UCS-2 encoded string to a solid antialiased 32-bit surface.
+
+    This function is identical to :func:`TTF_RenderUNICODE_LCD`, except that
+    any lines exceeding the specified wrap length will be wrapped to fit within
+    the given width.
+
+    `Note: Added in SDL_ttf 2.20.0`
+   
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        text (bytes): A UTF8-encoded bytestring of text to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the text.
+        bg (:obj:`SDL_Color`): The background fill color for the text.
+        wrapLength (int): The maximum width of the output surface (in pixels)
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered text, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderUNICODE_LCD_Wrapped"](font, text, fg, bg, wrapLength)
+
+def TTF_RenderGlyph_LCD(font, ch, fg, bg):
+    """Renders a unicode character to a 32-bit surface using a given font.
+
+    See :func:`TTF_RenderText_LCD` for more details on the rendering style,
+    and :func:`TTF_RenderGlyph_Solid` for additional usage information.
+    
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object to use.
+        ch (int): A unicode integer representing the glyph to render.
+        fg (:obj:`SDL_Color`): The color to use for rendering the glyph.
+        bg (:obj:`SDL_Color`): The background fill color for the glyph.
+
+    Returns:
+        POINTER(:obj:`SDL_Surface`): A pointer to the new surface containing the
+        rendered glyph, or a null pointer if there was an error.
+
+    """
+    return _ctypes["TTF_RenderGlyph_LCD"](font, ch, fg, bg)
+
+def TTF_RenderGlyph32_LCD(font, ch, fg, bg):
+    """Renders a unicode character to a 32-bit surface using a given font.
+
+    Functionally identical to :func:`TTF_RenderGlyph_LCD`, except it supports
+    32-bit character codes instead of just 16-bit ones.
+
+    `Note: Added in SDL_ttf 2.20.0`
+
+    """
+    return _ctypes["TTF_RenderGlyph32_LCD"](font, ch, fg, bg)
+
 TTF_RenderText = TTF_RenderText_Shaded
 TTF_RenderUTF8 = TTF_RenderUTF8_Shaded
 TTF_RenderUNICODE = TTF_RenderUNICODE_Shaded
@@ -1586,6 +1929,10 @@ TTF_RenderUNICODE = TTF_RenderUNICODE_Shaded
 def TTF_SetDirection(direction):
     """Sets the global text direction to use for rendering.
 
+    .. note:: This function has been deprecated in favor of
+              :func:`TTF_SetFontDirection` and should not be used in new
+              projects.
+
     This function lets you manually specify the direction in which SDL_ttf
     should render text, and can be set or changed at any time.
 
@@ -1619,6 +1966,10 @@ def TTF_SetDirection(direction):
 def TTF_SetScript(script):
     """Sets the global script (e.g. Arabic) to use for rendering text.
 
+    .. note:: This function has been deprecated in favor of
+              :func:`TTF_SetFontScriptName` and should not be used in new
+              projects.
+
     Setting the script gives the text renderer extra information about how
     to best shape words and characters for a given language. This can produce
     better results when rendering with non-Latin languages and fonts.
@@ -1646,6 +1997,58 @@ def TTF_SetScript(script):
     """
     return _ctypes["TTF_SetScript"](script)
 
+def TTF_SetFontDirection(font, direction):
+    """Sets the text direction to use for rendering a given font.
+
+    This function lets you manually specify the direction to use for rendering
+    text with a given font, using the following constants:
+
+    =============== =====================
+    Text Direction  Constant
+    =============== =====================
+    Left-to-right   ``TTF_DIRECTION_LTR``
+    Right-to-left   ``TTF_DIRECTION_RTL``
+    Top-to-bottom   ``TTF_DIRECTION_TTB``
+    Bottom-to-top   ``TTF_DIRECTION_BTT``
+    =============== =====================
+
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object to configure.
+        direction (int): A constant specifying the direction to use for
+            rendering text with the given font.
+
+    Returns:
+        int: 0 on success, -1 on error.
+
+    """
+    return _ctypes["TTF_SetFontDirection"](font, direction)
+
+def TTF_SetFontScriptName(font, script):
+    """Sets the script (e.g. Arabic) to use for rendering a given font.
+
+    Setting the script gives the text renderer extra information about how
+    to best shape words and characters for a given language. This can produce
+    better results when rendering with non-Latin languages and fonts.
+
+    The script type is specified as a 4-character ISO 15924 character code (e.g.
+    'Arab' for Arabic). A full list of possible 4-character script codes can be
+    found here: https://unicode.org/iso15924/iso15924-codes.html
+
+    `Note: Added in SDL_ttf 2.20.0`
+
+    Args:
+        font (:obj:`TTF_Font`): The font object to configure.
+        script (bytes): A 4-character ISO 15924 character code indicating the
+            script type to use for text shaping.
+
+    Returns:
+        int: 0 on success, -1 on error.
+
+    """
+    return _ctypes["TTF_SetFontScriptName"](font, script)
+
 def TTF_CloseFont(font):
     """Closes and frees the memory associated with a given font.
 
